#!/usr/bin/python3
# -- coding: UTF-8 --

import syslog
import dbus
from pydbus import SystemBus
import gi
gi.require_version('Gtk', '3.0')
from gi.repository import GLib, Gtk, Gio


class HidControl():
    """
    <node>
        <interface name='com.kylin.InputControl.hid'>
            <method name='DisableHidDevices' >
                <arg type='i' direction='out' name='ret'/>
            </method>
            <method name='EnableHidDevices' >
                <arg type='i' direction='out' name='ret'/>
            </method>
            <method name='GetHidDevices'>
                <arg type='i' direction='out' name='ret'/>
            </method>
        </interface>
    </node>
    """

    def __init__(self):
        try:
            self.sdk = SystemBus().get("com.kylin.kysdk.InputControl.hid",
                                   "/com/kylin/kysdk/InputControl/hid")
        except Exception:
            print("get sdk dbus error")
        

    def DisableHidDevices(self) -> int:
        syslog.syslog(syslog.LOG_DEBUG, "hid DisableHidDevices")
        try:
            rc = self.sdk.DisableHidDevices()
            syslog.syslog(syslog.LOG_DEBUG, "hid DisableHidDevices rc:{}".format(rc))
        except Exception:
            return -1
        return rc

    def EnableHidDevices(self) -> int:
        syslog.syslog(syslog.LOG_DEBUG, "hid EnableHidDevices")
        try:
            rc = self.sdk.EnableHidDevices()
            syslog.syslog(syslog.LOG_DEBUG, "hid EnableHidDevices rc:{}".format(rc))
        except Exception:
            return -1
        return rc

    def GetHidDevices(self) -> int:
        syslog.syslog(syslog.LOG_DEBUG, "hid GetHidDevices")
        try:
            rc = self.sdk.GetHidDevices()
            syslog.syslog(syslog.LOG_DEBUG, "hid GetHidDevices rc:{}".format(rc))
        except Exception:
            return -1
        return rc



if __name__ == '__main__':
    loop = GLib.MainLoop()
    bus = SystemBus()
    bus.publish("com.kylin.InputControl.hid", HidControl())
    loop.run()