#!/usr/bin/python3
# -- coding: UTF-8 --

import syslog
import dbus
from pydbus import SystemBus
import gi
gi.require_version('Gtk', '3.0')
from gi.repository import GLib, Gtk, Gio

class StorageControl():
    """
    <node>
        <interface name='com.kylin.StorageControl'>

            <method name='SetStatus' >
                <arg type='i' direction='in' name='status'/>
                <arg type='i' direction='out' name='ret'/>
            </method>

            <method name='GetStatus' >
                <arg type='i' direction='out' name='status'/>
            </method>
        </interface>
    </node>
    """
    def __init__(self):
        try:
            self.sdk = SystemBus().get("com.kylin.kysdk.StorageControl",
                                   "/com/kylin/kysdk/StorageControl")
        except Exception:
            print("get sdk dbus error")
        
    def SetStatus(self, status: int) -> int:
        try:
            rc = self.sdk.SetStatus(status)
            syslog.syslog(syslog.LOG_DEBUG, "storage SetStatus status:{} rc:{}".format(status, rc))
        except:
            return -1
        return rc 
    

    def GetStatus(self) -> int:
        try:
            rc = self.sdk.GetStatus()
            syslog.syslog(syslog.LOG_DEBUG, "storage GetStatus rc:{}".format(rc))
        except:
            return -1
        return rc 

if __name__ == '__main__':
    loop = GLib.MainLoop()
    bus = SystemBus()
    bus.publish("com.kylin.StorageControl", StorageControl())
    loop.run()