#!/usr/bin/python3
# -- coding: UTF-8 --

import sys
import syslog
import dbus
from pydbus import SystemBus
import gi
gi.require_version('Gtk', '3.0')
from gi.repository import GLib, Gtk, Gio

class VideoControl():
    """
    <node>
        <interface name='com.kylin.InputControl.video'>
            <method name='DisableVideoDevices'>
                <arg type='i' direction='out' name='ret'/>
            </method>
            <method name='EnableVideoDevices'>
                <arg type='i' direction='out' name='ret'/>
            </method>
            <method name='GetVideoDevices'>
                <arg type='i' direction='out' name='ret'/>
            </method>
        </interface>
    </node>
    """


    def __init__(self):
        try:
            syslog.syslog(syslog.LOG_DEBUG, "video init start")
            self.sdk = SystemBus().get("com.kylin.mdm.InputControl.video",
                                   "/com/kylin/mdm/InputControl/video")

        except Exception:
            print("get sdk dbus error")
        

    def DisableVideoDevices(self) -> int:
        self.name = SystemBus().get("org.freedesktop.DBus", "/org/freedesktop/DBus")
        bRet = self.name.NameHasOwner("com.kylin.mdm.InputControl.video")

        if bRet == False:
            syslog.syslog(syslog.LOG_DEBUG, "DisableVideoDevices video NameHasOwner bRet:{}".format(bRet))
            return -1

        self.sdk = SystemBus().get("com.kylin.mdm.InputControl.video",
                                   "/com/kylin/mdm/InputControl/video")

        try:
            rc = self.sdk.DisableVideoDevices()
            syslog.syslog(syslog.LOG_DEBUG, "video DisableVideoDevices rc:{}".format(rc))
        except Exception:
            return -1
        return rc

    def EnableVideoDevices(self) -> int:
        self.name = SystemBus().get("org.freedesktop.DBus", "/org/freedesktop/DBus")
        bRet = self.name.NameHasOwner("com.kylin.mdm.InputControl.video")

        if bRet == False:
            syslog.syslog(syslog.LOG_DEBUG, "EnableVideoDevices video NameHasOwner bRet:{}".format(bRet))
            return -1

        self.sdk = SystemBus().get("com.kylin.mdm.InputControl.video",
                                   "/com/kylin/mdm/InputControl/video")

        try:
            rc = self.sdk.EnableVideoDevices()
            syslog.syslog(syslog.LOG_DEBUG, "video EnableVideoDevices rc:{}".format(rc))
        except Exception:
            return -1
        return rc

    def GetVideoDevices(self) -> int:
        self.name = SystemBus().get("org.freedesktop.DBus", "/org/freedesktop/DBus")
        bRet = self.name.NameHasOwner("com.kylin.mdm.InputControl.video")

        #查看'/org/ukui/media'是否启动
        if bRet == False:
            syslog.syslog(syslog.LOG_DEBUG, "GetVideoDevices video NameHasOwner bRet:{}".format(bRet))
            return -1
            
        self.sdk = SystemBus().get("com.kylin.mdm.InputControl.video",
                                   "/com/kylin/mdm/InputControl/video")

        try:
            rc = self.sdk.GetVideoDevices()
            syslog.syslog(syslog.LOG_DEBUG, "Video GetVideoDevices rc:{}".format(rc))
        except Exception:
            return -1
        return rc



if __name__ == '__main__':
    loop = GLib.MainLoop()
    bus = SystemBus()
    bus.publish("com.kylin.InputControl.video", VideoControl())
    loop.run()