#!/usr/bin/python3
# -- coding: UTF-8 --

import syslog
import dbus
import dbus.service
from pydbus import SystemBus
import dbus.mainloop.glib
import gi
gi.require_version('Gtk', '3.0')
from gi.repository import GLib, Gtk, Gio

from dbus.mainloop.glib import DBusGMainLoop
DBusGMainLoop(set_as_default=True)

BUS_NAME = "com.kylin.mdm"
OBJ_NAME = "/com/kylin/mdm/SoundCardsCtl"
IFACE = "com.kylin.mdm.SoundCardsCtl"

class SoundControl(dbus.service.Object):
    """
    <node>
        <interface name="com.kylin.mdm.SoundCardsCtl">
            <method name="SetDeviceEnableRoot">
                <arg type="i" direction="out"/>
                <arg name="bEnable" type="b" direction="in"/>
            </method>
            <method name="GetDeviceEnableRoot">
                <arg type="b" direction="out"/>
            </method>
        </interface>
    </node>
    """

    def __init__(self):
        try:
            syslog.syslog(syslog.LOG_DEBUG, "__init__ SoundControl start")

            bus = dbus.SystemBus()
            bus_name = dbus.service.BusName(BUS_NAME, bus=bus)
            dbus.service.Object.__init__(self, bus_name, OBJ_NAME)

        except Exception:
            print("SoundControl get sdk dbus error")

    @dbus.service.method(dbus_interface=IFACE,
                         in_signature="b", out_signature="i")
    def SetDeviceEnableRoot(self, bEnable: bool) -> int:
        syslog.syslog(syslog.LOG_DEBUG, "sound SetDeviceEnableRoot bEnable:{}".format(bEnable))

        #因声音管控启动较慢，所以在接口中初始化
        self.name = SystemBus().get("org.freedesktop.DBus", "/org/freedesktop/DBus")
        bRet = self.name.NameHasOwner("org.ukui.media")

        #查看'/org/ukui/media'是否启动
        if bRet == False:
            syslog.syslog(syslog.LOG_DEBUG, "sound SetDeviceEnableRoot NameHasOwner bRet:{}".format(bRet))
            return -1

        self.dbus = SystemBus().get('org.ukui.media', '/org/ukui/media')
        
        #获取声卡状态
        bRet = self.GetDeviceEnableRoot()
        
        # 现有声卡状态与获取的声卡状态一致，直接返回成功
        if bRet == bEnable:
            return 0

        try:
            rc = -1
            rc = self.dbus.SetDeviceEnableRoot(bEnable)
            syslog.syslog(syslog.LOG_DEBUG, "sound SetDeviceEnableRoot bEnable:{} rc:{}".format(bEnable, rc))

        except Exception:
            syslog.syslog(syslog.LOG_DEBUG, "sound SetDeviceEnableRoot error")
            return -1
            
        return rc  

    @dbus.service.method(dbus_interface=IFACE,
                         in_signature="", out_signature="b")
    def GetDeviceEnableRoot(self) -> bool:
        syslog.syslog(syslog.LOG_DEBUG, "sound GetDeviceEnableRoot")

        #因声音管控启动较慢，所以在接口中初始化
        self.name = SystemBus().get("org.freedesktop.DBus", "/org/freedesktop/DBus")
        bRet = self.name.NameHasOwner("org.ukui.media")

        #查看'/org/ukui/media'是否启动
        if bRet == False:
            syslog.syslog(syslog.LOG_DEBUG, "sound GetDeviceEnableRoot NameHasOwner bRet:{}".format(bRet))
            return False

        self.dbus = SystemBus().get('org.ukui.media', '/org/ukui/media')

        try:
            rc = False
            rc = self.dbus.GetDeviceEnableRoot()
            syslog.syslog(syslog.LOG_DEBUG, "sound GetDeviceEnableRoot rc:{}".format(rc))

        except Exception:
            syslog.syslog(syslog.LOG_DEBUG, "sound GetDeviceEnableRoot error")
            return False

        return rc  

if __name__ == '__main__':
    a = SoundControl()

    loop = GLib.MainLoop()
    loop.run()